#
# spec file for package bowtie2
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global simde_version 0.7.2
%ifarch aarch64
%define _lto_cflags %{nil}
%endif
Name:           bowtie2
Version:        2.5.1
Release:        bp156.2.21
Summary:        Fast and memory-efficient short read aligner
License:        GPL-3.0-only
Group:          Productivity/Scientific/Other
URL:            http://bowtie-bio.sourceforge.net/bowtie2/index.shtml
Source0:        https://github.com/BenLangmead/bowtie2/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/simd-everywhere/simde/archive/v%{simde_version}.tar.gz#/simde-%{simde_version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)
ExclusiveArch:  x86_64 s390x ppc64le ppc64 aarch64

%description
Bowtie 2 is an ultrafast and memory-efficient tool for aligning sequencing
reads to long reference sequences. It is particularly good at aligning
reads of about 50 up to 100s or 1,000s of characters, and particularly good
at aligning to relatively long (e.g. mammalian) genomes. Bowtie 2 indexes
the genome with an FM Index to keep its memory footprint small: for the
human genome, its memory footprint is typically around 3.2 GB. Bowtie 2
supports gapped, local, and paired-end alignment modes.

%prep
%setup -q
%setup -q -b 1
pushd third_party
rmdir simde
ln -s ../../simde-*/ simde
popd
# Workaround to find simde/x86/*.h on aarch64
ln -s ../simde-*/simde simde

%build
%ifarch aarch64
sed -i -e 's/-msse2//' CMakeLists.txt
sed -i -e 's/-m64//' CMakeLists.txt
%endif
# Note: RelWithDebInfo isn't supported and assumes fully unoptimised DEBUG mode; use Release mode instead
%cmake \
%ifarch aarch64
  -DNO_POPCNT_CAPABILITY=1 \
%endif
  -DCMAKE_BUILD_TYPE=Release

%cmake_build

%install
%cmake_install

# CONVERT env HASHBANGS TO USE DIRECT EXECUTABLE
perlbin=`which perl`
sed -i "s:%{_bindir}/env perl:${perlbin}:" %{buildroot}%{_bindir}/bowtie2
sed -i "s:%{_bindir}/env python:%{_bindir}/python:" %{buildroot}%{_bindir}/bowtie2-{build,inspect}

%fdupes %{buildroot}%{_bindir}

%files
%doc AUTHORS MANUAL NEWS TUTORIAL BOWTIE2_VERSION README.md
%license LICENSE
%{_bindir}/bowtie2
%{_bindir}/bowtie2-build*
%{_bindir}/bowtie2-inspect*
%{_bindir}/bowtie2-align*

%changelog
* Wed Jan 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.5.1:
  * Fixed an issue affecting bowtie2 alignment accuracy.
  * Updated the versions of the NCBI NGS and VDB libraries used by
    bowtie2.
  * Fixed a segmentation fault that would occur while aligning SRA
    data.
  * Fixed an issue preventing --un-mates from properly saving
    unaligned mates.
* Sun Nov 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.5.0:
  * Overall improvements in the use of prefetch instructions.
  * Made input/output fully asynchronous by using a dedicated
    thread.
  * Added support for AVX2 256-bit instructions with can be
    enabled by setting the SSE_AXV2 environment variable at
    compile time.
  * Fixed an issue causing bowtie2 to crash when processing ZSTD
    files with high compression ratios.
  * Changed the way that unique alignments are counted in summary
    message to better match up with filters on SAM output.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.5:
  * Fixed issues with bowtie2 BAM parser that would cause bowtie2
    to crash when processing input that was encoded with tools
    other than samtools e.g. Picard.
  * Fixed an issue causing bowtie2 to drop certain optional fields
    when when aligning BAM reads with the --preserve-tags option.
  * Fixed an issue causing bowtie2 to produce mangled SAM output
    when specifying --sam-append-comment together with the
  - -passthrough option.
  * Appended GO:query to SAM @HD entry to indicate that reads are
    grouped by query name, bump SAM version to 1.5 to indicate
    support for this change.
- Update simde to version 0.7.2.
* Fri Jul  2 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.4:
  * Fixed an issue that would sometimes cause deadlocks in bowtie2
    when running multithreaded.
* Fri May 14 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.3:
  * Replaced TBB concurrency with C++ threads.
  * Added native support for processing Zstd-compressed read files
    to bowtie2.
  * Added native support for processing Zstd-compressed
    reference-genome files to bowtie2-build.
  * Fixed an issue causing `bowtie2` to report incorrect
    alignments on big-endian machines.
  * Fixed an issue causing `bowtie2` to incorrectly process BAM
    files on big-endian machines.
  * Fixed an issue causing Bowtie2 to set an incorrect MAPQ when
    AS and XS are the maximum for read length.
  * Add support for building on Apple M1 processors.
- Update simde to version 0.7.0.
- Drop BuildRequires tbb-devel: no longer required.
- RelWithDebInfo isn't supported and assumes fully unoptimised
  Debug mode; use Release mode instead by passing
  `-DCMAKE_RELEASE_TYPE=Release` to cmake.
* Wed Oct 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Actually update bowtie2 source to version 2.4.2 (fixing previous
  revision).
- Drop patches incorporated upstream:
  * bowtie2-processor_support.patch (commit ebb07cf).
  * bowtie2-cmake-install-targets.patch (commit c9d92ce).
- Package README.md file as doc.
* Fri Oct 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.2:
  * Fixed an issue that would cause the `bowtie2` wrapper script
    to throw an error when using wrapper-specific arguments.
  * Added new `--sam-append-comment` flag that appends comment
    from FASTA/Q read to corresponding SAM record.
  * Fixed an issue that would cause qupto, `-u`, to overflow when
    there are >= 2^32 query sequences
    (gh#BenLangmead/bowtie2#312).
  * Fixed an issue that would cause bowtie2-build script to
    incorrectly process reference files.
- Drop _service file and use tagged version of simde instead (at
  version 0.6.0); correspondingly drop the obsinfo and obscpio
  files as well.
* Mon Jun 15 2020 Pierre Bonamy <flyos@mailoo.org>
- Added bowtie2-processor_support.patch to fix GCC10 build fail
- Added %%fdupes in the spec files to handle duplicated binary files
* Tue May 26 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.1:
  * Fixed an issue that would cause the bowtie2 wrapper script to
    incorrectly process certain arguments.
- Changes from version 2.4.0:
  * Fixed an issue in BAM pattern source where one thread would
    prematurely close the read file pointer resulting in other
    threads crashing because of "Bad file descriptor" errors.
  * Fixed an issue that would cause bowtie2 to crash with
    `--no-1mm-upfront` specified.
  * Modified bowtie2-build script to better handle of flags and
    positional parameters.
  * Migrated all python scripts to python3.
  * Added support for wildcards in input files to bowtie2 wrapper
    script e.g.  `bowtie2 -x index -q *.fq` as opposed to `bowtie2
  - x index -q 1.fq,2.fq,3.fq...`.
  * Fixed an issue causing bowtie2 to incorrectly process read
    names see [gh#BenLangmead/bowtie2#265].
  * Added support for allowing presets to be overridden by more
    specific options e.g `bowtie2 -x index --local
  - -very-fast-local --L22 -q reads.fq` will cause bowtie2 to use
    a seed length of 22 instead of a seed length of 25 that's
    configured for `--very-fast-local` preset.
  * Modified SAM output for `-k`/`-a` so that supplementary
    alignments get assigned a MAPQ of 255.
  * Fixed an issue that would cause bowtie2-build to not generate
    reverse index files.
  * Added preliminary support for ppc64le architectures with the
    help of SIMDE project see [gh#BenLangmead/bowtie2#271] for
    details.
  * Fixed an issue causing bowtie2 to incorrectly calculate the
    MAPQ when `--mp` was specified in combination with
    `--ignore-quals`.
- Add bowtie2-cmake-install-targets.patch to fix cmake scripts,
  specfically adding install targets and fixing tests (still does
  not work) [gh#BenLangmead/bowtie2#292].
- Use cmake for building (BuildRequires: cmake); adapt
  appropriately for aarch64.
- Use pkgconfig based BuildRequires for zlib.
* Tue May 12 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix aarch64 build with:
  * simde sources
  * export POPCNT_CAPABILITY=0
* Sat Nov 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Use %%%%license to install LICENSE file.
* Thu Nov  7 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.3.5.1:
  * Added official support for BAM input files.
  * Added official support for CMake build system.
  * Added changes to Makefile for creating Reproducible builds
    [gh#BenLangmead/bowtie2#210].
  * Fix an issue whereby building on aarch64 would require
    patching sed commands [gh#BenLangmead/bowtie2#243].
  * Fix an issue whereby `bowtie2` would incorrectly throw an
    error while processing `--interleaved` input.
- Changes from version 2.3.5:
  * Added support for obtaining input reads directly from the
    Sequence Read Archive, via NCBI's [NGS language
    bindings](https://github.com/ncbi/ngs).  This is activated via
    the [`--sra-acc`](manual.shtml#bowtie2-options-sra-acc)
    option.  This implementation is based on Daehwan Kim's in
    [HISAT2](https://ccb.jhu.edu/software/hisat2).  Supports both
    unpaired and paired-end inputs.
  * Bowtie 2 now compiles on ARM architectures (via
    [gh#BenLangmead/bowtie2#216].
  * `--interleaved` can now be combined with FASTA inputs (worked
    only with FASTQ before).
  * Fixed issue whereby large indexes were not successfully found
    in the `$BOWTIE2_INDEXES` directory.
  * Fixed input from FIFOs (e.g. via process substitution) to
    distinguish gzip-compressed versus uncompressed input.
  * Fixed issue whereby arguments containing `bz2` `lz4` were
    misinterpretted as files.
  * Fixed several compiler warnings.
  * Fixed issue whereby both ends of a paired-end read could have
    negative TLEN if they exactly coincided
  * Fixed issue whereby `bowtie2-build` would hang on end-of-file
    [gh#BenLangmead/bowtie2#228].
  * Fixed issue whereby wrapper script would sometimes create
    zombie processes [gh#BenLangmead/bowtie2#51].
  * Fixed issue whereby `bowtie2-build` and `bowtie2-inspect`
    wrappers would fail on some versions of Python/PyPy.
  * Replaced old, unhelpful `README.md` in the project with a
    version that includes badges, links and some highlights from
    the manual.
* Wed Feb 28 2018 badshah400@gmail.com
- Update to version 2.3.4.1:
  * Fixed an issue with --reorder that caused bowtie2 to crash
    while reordering SAM output
- Changes from version 2.3.4:
  * Fixed major issue causing corrupt SAM output when using many
    threads (-p/--threads) on certain systems.
  * Fixed an issue whereby bowtie2 processes could overwrite each
    others' named pipes on HPC systems.
  * Fixed an issue causing bowtie2-build and bowtie2-inspect to
    return prematurely on Windows.
  * Fixed issues raised by compiler "sanitizers" that could
    potentially have caused memory corruption or undefined
    behavior.
  * Added the "continuous FASTA" input format (-F) for aligning
    all the k-mers in the sequences of a FASTA file. Useful for
    determining mapability of regions of the genome, and similar
    tasks.
- Run sed on binaries to modify env based hashbangs to ones that
  directly call executables.
- Drop bowtie2-gcc6.patch; incorporated upstream.
* Mon Sep  4 2017 mpluskal@suse.com
- Update to version 2.3.2:
  * Added support for interleaved paired-end FASTQ inputs
    (--interleaved)
  * Now reports MREVERSE SAM flag for unaligned end when only one
    end of a pair aligns
  * Fixed issue where first character of some read names was
    omitted from SAM output when using tabbed input formats.
  * Added --sam-no-qname-trunc option.
  * Fixed compilation error caused by pointer comparison issue in aligner_result.cpp
  * Removed termcap and readline dependencies introduced in v2.3.1
  * Fixed compilation issues caused by gzbuffer function when
    compiling with zlib v1.2.3.5 and earlier.
  * Fixed issue that would cause Bowtie 2 hang when aligning FASTA
    inputs with more than one thread
- Changes for version 2.3.0:
  * Code related to read parsing was completely rewritten to improve
    scalability to many threads.
  * TBB is now the default threading library.
  * Bowtie now uses a queue-based lock rather than a spin or
    heavyweight lock.
  * Unnecessary thread synchronization removed
  * Fixed issue with parsing FASTA records with greater-than symbol
    in the name
  * Changed default for --bmaxdivn to yield better memory footprint
    and running time when building an index with many threads
- Add bowtie2-gcc6.patch (fixes compilation with gcc6+)
- Build using optflags
- Update download url
- Small package cleanup with spec-cleaner
* Thu May  5 2016 flyos@mailoo.org
- Initial release
